<?php
/**
 * Theme Customizer
 *
 * @package fred
 */

function fred_customize_register( $wp_customize ) {

  class fred_customize_number_control extends WP_Customize_Control {
    public $type = 'fred_number_field';
    public function render_content() {
      ?>
      <label>
        <span class="customize-control-title">
          <?php echo esc_html($this->label); ?>
        </span>
        <input type="number" min="1" max="10000" value="<?php echo esc_attr($this->value()); ?>" <?php $this->link(); ?> />
      </label>
      <?php
    }
  }

  $wp_customize->add_panel( 'theme_options' ,array(
    'title' => esc_html__( 'Theme Options', 'fred' ),
    'description' => '',
  ));

  //----------------------------------------------------------------------------------
  // Section: Colors
  //----------------------------------------------------------------------------------
  $wp_customize->add_section( 'colors_general' , array(
    'title' => esc_html__('Colors', 'fred'),
    'panel' => 'theme_options',
    'priority' => 1,
  ));
  $wp_customize->add_setting( 'theme_color', array(
    'default' => '#f47d89',
    'sanitize_callback' => 'sanitize_hex_color_no_hash',
    'sanitize_js_callback' => 'maybe_hash_hex_color',
  ));
  $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'theme_color', array(
    'label' => esc_html__( 'Theme Color', 'fred' ),
    'section' => 'colors_general',
  )));
  
  //----------------------------------------------------------------------------------
  // Section: General Settings
  //----------------------------------------------------------------------------------
  $wp_customize->add_section( 'general_settings_section' , array(
    'title' => esc_html__('General Settings', 'fred'),
    'panel' => 'theme_options',
    'priority' => 2,
  ));
  $wp_customize->add_setting('blog_pagination',array(
    'default' => 'pagination',
    'sanitize_callback' => 'fred_sanitize_blog_pagination',
  ));
  $wp_customize->add_control('blog_pagination',array(
    'label' => esc_html__('Blog Pagination or Navigation', 'fred'),
    'section' => 'general_settings_section',
    'settings' => 'blog_pagination',
    'type' => 'radio',
    'choices' => array(
      'pagination' => esc_html__('Pagination', 'fred'),
      'navigation' => esc_html__('Navigation', 'fred'),
    ),
  ));
  $wp_customize->add_setting('header_title',array(
    'default' => false,
    'sanitize_callback' => 'fred_sanitize_checkbox',
  ));
  $wp_customize->add_control('header_title',array(
    'label' => esc_html__('Hide Header Title Text', 'fred'),
    'section' => 'general_settings_section',
    'settings' => 'header_title',
    'type' => 'checkbox',
  ));
  $wp_customize->add_setting('blog_layout',array(
    'default' => 'right_sidebar',
    'sanitize_callback' => 'fred_sanitize_blog_layout',
  ));
  $wp_customize->add_control('blog_layout',array(
    'type' => 'select',
    'label' => esc_html__('Blog Layout', 'fred'),
    'section' => 'general_settings_section',
    'choices' => array(
      'right_sidebar' => esc_html__('Right sidebar', 'fred'),
      'left_sidebar' => esc_html__('Left sidebar', 'fred'),
      'one_column' => esc_html__('One column', 'fred'),
    ),
  ));
  $wp_customize->add_setting('blog_excerpt_type',array(
    'default' => 'excerpt',
    'sanitize_callback' => 'fred_sanitize_blog_excerpt_type',
  ));
  $wp_customize->add_control('blog_excerpt_type',array(
    'type' => 'select',
    'label' => esc_html__('Use Excerpt or "Read More tag"', 'fred'),
    'section' => 'general_settings_section',
    'choices' => array(
      'excerpt' => esc_html__('Excerpt', 'fred'),
      'more-tag' => esc_html__('Read More tag', 'fred'),
    ),
  ));
  $wp_customize->add_setting('blog_excerpt_length',array(
    'default' => 30,
    'sanitize_callback' => 'fred_sanitize_number_intval',
  ));
  $wp_customize->add_control(new fred_customize_number_control($wp_customize,'blog_excerpt_length',array(
    'label' => esc_html__('Excerpt Length (Number of Words)', 'fred'),
    'section' => 'general_settings_section',
    'settings' => 'blog_excerpt_length',
  )));
  $wp_customize->add_setting('general_show_totop_btn',array(
    'default' => 1,
    'sanitize_callback' => 'fred_sanitize_checkbox',
  ));
  $wp_customize->add_control('general_show_totop_btn',array(
    'type' => 'checkbox',
    'label' => esc_html__('Show "Back to top" button', 'fred'),
    'section' => 'general_settings_section',
  ));

  //----------------------------------------------------------------------------------
  // Section: Social Media Icons 
  //----------------------------------------------------------------------------------
  $wp_customize->add_section( 'fred_social', array(
    'title' => esc_html__( 'Social Media Icons', 'fred' ),
    'panel' => 'theme_options',
    'priority' => 3,
  ));
  $wp_customize->add_setting( 'social_email', array(
    'default' => '',
    'sanitize_callback' => 'sanitize_email',
  ));
  $wp_customize->add_control( 'social_email', array(
    'label' => esc_html__( 'Email Address', 'fred' ),
    'section' => 'fred_social',
    'settings' => 'social_email',
    'type' => 'text',
  ));
  $wp_customize->add_setting( 'social_skype', array(
    'default' => '',
    'sanitize_callback' => 'sanitize_text_field',
  ));
  $wp_customize->add_control( 'social_skype', array(
    'label' => esc_html__( 'Skype', 'fred' ),
    'section' => 'fred_social',
    'settings' => 'social_skype',
    'type' => 'text',
  ));
  $wp_customize->add_setting( 'social_facebook', array(
    'default' => '',
    'sanitize_callback' => 'esc_url_raw',
  ));
  $wp_customize->add_control( 'social_facebook', array(
    'label' => esc_html__( 'Facebook', 'fred' ),
    'section' => 'fred_social',
    'settings' => 'social_facebook',
    'type' => 'text',
  ));
  $wp_customize->add_setting( 'social_twitter', array(
    'default' => '',
    'sanitize_callback' => 'esc_url_raw',
  ));
  $wp_customize->add_control( 'social_twitter', array(
    'label' => esc_html__( 'Twitter', 'fred' ),
    'section' => 'fred_social',
    'settings' => 'social_twitter',
    'type' => 'text',
  ));
  $wp_customize->add_setting( 'social_google_plus', array(
    'default' => '',
    'sanitize_callback' => 'esc_url_raw',
  ));
  $wp_customize->add_control( 'social_google_plus', array(
    'label' => esc_html__( 'Google Plus', 'fred' ),
    'section' => 'fred_social',
    'settings' => 'social_google_plus',
    'type' => 'text',
  ));
  $wp_customize->add_setting( 'social_youtube', array(
    'default' => '',
    'sanitize_callback' => 'esc_url_raw',
  ));
  $wp_customize->add_control( 'social_youtube', array(
    'label' => esc_html__( 'YouTube', 'fred' ),
    'section' => 'fred_social',
    'settings' => 'social_youtube',
    'type' => 'text',
  ));
  $wp_customize->add_setting( 'social_instagram', array(
    'default' => '',
    'sanitize_callback' => 'esc_url_raw',
  ));
  $wp_customize->add_control( 'social_instagram', array(
    'label' => esc_html__( 'Instagram', 'fred' ),
    'section' => 'fred_social',
    'settings' => 'social_instagram',
    'type' => 'text',
  ));
  $wp_customize->add_setting( 'social_pinterest', array(
    'default' => '',
    'sanitize_callback' => 'esc_url_raw',
  ));
  $wp_customize->add_control( 'social_pinterest', array(
    'label' => esc_html__( 'Pinterest', 'fred' ),
    'section' => 'fred_social',
    'settings' => 'social_pinterest',
    'type' => 'text',
  ));
  $wp_customize->add_setting( 'social_linkedin', array(
    'default' => '',
    'sanitize_callback' => 'esc_url_raw',
  ));
  $wp_customize->add_control( 'social_linkedin', array(
    'label' => esc_html__( 'LinkedIn', 'fred' ),
    'section' => 'fred_social',
    'settings' => 'social_linkedin',
    'type' => 'text',
  ));
  $wp_customize->add_setting( 'social_tumblr', array(
    'default' => '',
    'sanitize_callback' => 'esc_url_raw',
  ));
  $wp_customize->add_control( 'social_tumblr', array(
    'label' => esc_html__( 'Tumblr', 'fred' ),
    'section' => 'fred_social',
    'settings' => 'social_tumblr',
    'type' => 'text',
  ));
  $wp_customize->add_setting( 'social_flickr', array(
    'default' => '',
    'sanitize_callback' => 'esc_url_raw',
  ));
  $wp_customize->add_control( 'social_flickr', array(
    'label' => esc_html__( 'Flickr', 'fred' ),
    'section' => 'fred_social',
    'settings' => 'social_flickr',
    'type' => 'text',
  ));

  //----------------------------------------------------------------------------------
  // Section: Slider
  //----------------------------------------------------------------------------------
  $wp_customize->add_section( 'fred_slider', array(
    'title' => esc_html__( 'Slider', 'fred' ),
    'panel' => 'theme_options',
    'priority' => 4,
  ));
  $wp_customize->add_setting('activate_slider',array(
    'default' => false,
    'sanitize_callback' => 'fred_sanitize_checkbox',
  ));
  $wp_customize->add_control('activate_slider',array(
    'label' => esc_html__('Check to activate slider', 'fred'),
    'section' => 'fred_slider',
    'settings' => 'activate_slider',
    'type' => 'checkbox',
  ));

  $wp_customize->add_setting( 'slider_image1', array(
    'default' => '',
    'sanitize_callback' => 'sanitize_text_field',
  ));
  $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'slider_image1', array(
    'label' => esc_html__( 'Image Upload #1', 'fred' ),
    'description' => esc_html__( 'Upload slider image', 'fred' ),
    'section' => 'fred_slider',
    'settings' => 'slider_image1',
  ) ));
  $wp_customize->add_setting( 'slider_title1', array(
    'default' => '',
    'sanitize_callback' => 'sanitize_text_field',
  ));
  $wp_customize->add_control( 'slider_title1', array(
    'description' => esc_html__( 'Enter title for your slider', 'fred' ),
    'section' => 'fred_slider',
    'settings' => 'slider_title1',
    'type' => 'text',
  ));
  $wp_customize->add_setting( 'slider_text1', array(
    'default' => '',
    'sanitize_callback' => 'sanitize_text_field',
  ));
  $wp_customize->add_control( 'slider_text1', array(
    'description' => esc_html__( 'Enter your slider description', 'fred' ),
    'section' => 'fred_slider',
    'settings' => 'slider_text1',
    'type' => 'text',
  ));
  $wp_customize->add_setting( 'slider_link1', array(
    'default' => '',
    'sanitize_callback' => 'esc_url_raw',
  ));
  $wp_customize->add_control( 'slider_link1', array(
    'description' => esc_html__( 'Enter link to redirect slider when clicked', 'fred' ),
    'section' => 'fred_slider',
    'settings' => 'slider_link1',
    'type' => 'text',
  ));
  
  $wp_customize->add_setting( 'slider_image2', array(
    'default' => '',
    'sanitize_callback' => 'sanitize_text_field',
  ));
  $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'slider_image2', array(
    'label' => esc_html__( 'Image Upload #2', 'fred' ),
    'description' => esc_html__( 'Upload slider image', 'fred' ),
    'section' => 'fred_slider',
    'settings' => 'slider_image2',
  ) ));
  $wp_customize->add_setting( 'slider_title2', array(
    'default' => '',
    'sanitize_callback' => 'sanitize_text_field',
  ));
  $wp_customize->add_control( 'slider_title2', array(
    'description' => esc_html__( 'Enter title for your slider', 'fred' ),
    'section' => 'fred_slider',
    'settings' => 'slider_title2',
    'type' => 'text',
  ));
  $wp_customize->add_setting( 'slider_text2', array(
    'default' => '',
    'sanitize_callback' => 'sanitize_text_field',
  ));
  $wp_customize->add_control( 'slider_text2', array(
    'description' => esc_html__( 'Enter your slider description', 'fred' ),
    'section' => 'fred_slider',
    'settings' => 'slider_text2',
    'type' => 'text',
  ));
  $wp_customize->add_setting( 'slider_link2', array(
    'default' => '',
    'sanitize_callback' => 'esc_url_raw',
  ));
  $wp_customize->add_control( 'slider_link2', array(
    'description' => esc_html__( 'Enter link to redirect slider when clicked', 'fred' ),
    'section' => 'fred_slider',
    'settings' => 'slider_link2',
    'type' => 'text',
  ));
  
  $wp_customize->add_setting( 'slider_image3', array(
    'default' => '',
    'sanitize_callback' => 'sanitize_text_field',
  ));
  $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'slider_image3', array(
    'label' => esc_html__( 'Image Upload #3', 'fred' ),
    'description' => esc_html__( 'Upload slider image', 'fred' ),
    'section' => 'fred_slider',
    'settings' => 'slider_image3',
  ) ));
  $wp_customize->add_setting( 'slider_title3', array(
    'default' => '',
    'sanitize_callback' => 'sanitize_text_field',
  ));
  $wp_customize->add_control( 'slider_title3', array(
    'description' => esc_html__( 'Enter title for your slider', 'fred' ),
    'section' => 'fred_slider',
    'settings' => 'slider_title3',
    'type' => 'text',
  ));
  $wp_customize->add_setting( 'slider_text3', array(
    'default' => '',
    'sanitize_callback' => 'sanitize_text_field',
  ));
  $wp_customize->add_control( 'slider_text3', array(
    'description' => esc_html__( 'Enter your slider description', 'fred' ),
    'section' => 'fred_slider',
    'settings' => 'slider_text3',
    'type' => 'text',
  ));
  $wp_customize->add_setting( 'slider_link3', array(
    'default' => '',
    'sanitize_callback' => 'esc_url_raw',
  ));
  $wp_customize->add_control( 'slider_link3', array(
    'description' => esc_html__( 'Enter link to redirect slider when clicked', 'fred' ),
    'section' => 'fred_slider',
    'settings' => 'slider_link3',
    'type' => 'text',
  ));
  
  $wp_customize->add_setting( 'slider_image4', array(
    'default' => '',
    'sanitize_callback' => 'sanitize_text_field',
  ));
  $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'slider_image4', array(
    'label' => esc_html__( 'Image Upload #4', 'fred' ),
    'description' => esc_html__( 'Upload slider image', 'fred' ),
    'section' => 'fred_slider',
    'settings' => 'slider_image4',
  ) ));
  $wp_customize->add_setting( 'slider_title4', array(
    'default' => '',
    'sanitize_callback' => 'sanitize_text_field',
  ));
  $wp_customize->add_control( 'slider_title4', array(
    'description' => esc_html__( 'Enter title for your slider', 'fred' ),
    'section' => 'fred_slider',
    'settings' => 'slider_title4',
    'type' => 'text',
  ));
  $wp_customize->add_setting( 'slider_text4', array(
    'default' => '',
    'sanitize_callback' => 'sanitize_text_field',
  ));
  $wp_customize->add_control( 'slider_text4', array(
    'description' => esc_html__( 'Enter your slider description', 'fred' ),
    'section' => 'fred_slider',
    'settings' => 'slider_text4',
    'type' => 'text',
  ));
  $wp_customize->add_setting( 'slider_link4', array(
    'default' => '',
    'sanitize_callback' => 'esc_url_raw',
  ));
  $wp_customize->add_control( 'slider_link4', array(
    'description' => esc_html__( 'Enter link to redirect slider when clicked', 'fred' ),
    'section' => 'fred_slider',
    'settings' => 'slider_link4',
    'type' => 'text',
  ));
}
add_action( 'customize_register', 'fred_customize_register' );
