<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package fred
 */

if (!function_exists('fred_post_excerpt')) {
  function fred_post_excerpt() {
    $excerpt_type = get_theme_mod('blog_excerpt_type', 'excerpt');
    if ($excerpt_type == 'excerpt') {
      ?>

      <!-- excerpt -->
      <div class="entry-content clearfix">
        <?php the_excerpt(); ?>
      </div>
      <!-- end excerpt -->

      <?php
    } else {
      ?>

      <!-- excerpt (post content) -->
      <div class="entry-content clearfix">
        <?php the_content('[...]', false); ?>
      </div>
      <!-- end excerpt (post content) -->

      <?php
    }
  }
}

if (!function_exists('fred_slider')) {
  function fred_slider() {
?>
  <div class="slider-wrap">
    <div class="slider-cycle">
      <?php
      for( $i = 1; $i <= 4; $i++ ) {
        $fred_slider_title = get_theme_mod( 'slider_title'.$i , '' );
        $fred_slider_text  = get_theme_mod( 'slider_text'.$i  , '' );
        $fred_slider_image = get_theme_mod( 'slider_image'.$i , '' );
        $fred_slider_link  = get_theme_mod( 'slider_link'.$i  , '' );
        if( !empty( $fred_slider_image ) ) {
          ?>
          <section class="featured-slider">
            <div class="slider-image-wrap">
              <img alt="<?php echo esc_attr( $fred_slider_title ); ?>" src="<?php echo esc_url( $fred_slider_image ); ?>">
              </div>
              <?php if( !empty( $fred_slider_title ) || !empty( $fred_slider_text ) ) { ?>
                <article id="slider-text-box">
                  <div class="inner-wrap">
                    <div class="slider-text-wrap">
<?php if( !empty( $fred_slider_title )  ) { ?>
<span class="slider-title clearfix">
<a title="<?php echo esc_attr( $fred_slider_title ); ?>" <?php if(!empty($fred_slider_link)){ ?> href="<?php echo esc_url( $fred_slider_link ); ?>"<?php }?>><?php echo esc_html( $fred_slider_title ); ?></a>
</span>
<?php } ?>
<?php if( !empty( $fred_slider_text )  ) { ?>
<span class="slider-content"><?php echo esc_html( $fred_slider_text ); ?></span>
<?php } ?>
                    </div>
                  </div>
              </article>
            <?php } ?>
          </section>
        <?php
        }
      }
      ?>
    </div>
    <nav id="controllers" class="clearfix">
    </nav>
  </div>
<?php
  }
}

if (!function_exists('fred_page_header')) {
  function fred_page_header(){
    // author page
    if (is_author()) {
?>
      <header class="page-header">
        <h1 class="page-title"><?php the_archive_title();?></h1>
        <?php if (get_the_author_meta('description')) { ?>
        <div class="archive-description"><?php the_author_meta('description'); ?></div>
        <?php }?>
      </header><!-- .page-header -->
<?php
    // category/tag page
    } else if (is_category() || is_tag()) {
?>
      <header class="page-header">
        <h1 class="page-title"><?php the_archive_title();?></h1>
        <?php if (get_the_archive_description()) { ?>
        <div class="archive-description"><?php the_archive_description();?></div>
        <?php }?>
      </header><!-- .page-header -->
<?php
    // search results page
    } else if (is_search()) { 
?>
      <header class="page-header">
        <h1 class="page-title"><?php printf( esc_html__( 'Search Results for: %s', 'fred' ), '<span>' . get_search_query() . '</span>' );?></h1>
      </header><!-- .page-header -->
<?php
    // archive page
    } else if (is_archive()) {
?>
      <header class="page-header">
        <h1 class="page-title"><?php the_archive_title();?></h1>
      </header><!-- .page-header -->
<?php
    }
  }
}

if (!function_exists('fred_excerpt_length')) {
  function fred_excerpt_length($length) {
    $excerpt_length = get_theme_mod('blog_excerpt_length', 30);
    if ($excerpt_length) {
      $excerpt_length = intval($excerpt_length);
    } else {
      $excerpt_length = 30;
    }
    return $excerpt_length;
  }
}
add_filter('excerpt_length', 'fred_excerpt_length');

if (!function_exists('fred_editor_style')) {
  function fred_editor_style() {

    // add stylesheets
    add_editor_style(array(
      'assets/css/editor-style.css',
      'assets/font-awesome/css/font-awesome.min.css'
    ));

  }
}
add_action('init', 'fred_editor_style');

if (!function_exists('fred_get_custom_style')) {
  function fred_get_custom_style(){
    $css = '';
    $primary_color = esc_attr( get_theme_mod( 'theme_color' ) );
    if ( $primary_color ) {
        $primary_color = '#'.$primary_color;
$css .= '
blockquote{
  border-left:4px solid '.$primary_color.';
}
button,
input[type="button"],
input[type="reset"],
input[type="submit"]{
  background:'.$primary_color.';
}
input[type="text"]:focus,
input[type="email"]:focus,
input[type="url"]:focus,
input[type="password"]:focus,
input[type="search"]:focus,
input[type="number"]:focus,
input[type="tel"]:focus,
input[type="range"]:focus,
input[type="date"]:focus,
input[type="month"]:focus,
input[type="week"]:focus,
input[type="time"]:focus,
input[type="datetime"]:focus,
input[type="datetime-local"]:focus,
input[type="color"]:focus,
textarea:focus{
  border:1px solid '.$primary_color.';
}
a{
  color:'.$primary_color.';
}
a:hover,
a:focus,
a:active{
  color:'.$primary_color.';
}
.site-header{
  border-bottom: 3px solid '.$primary_color.';
}
.info-social a:hover i,
.info-social a:focus i{
  color:'.$primary_color.';
}
.main-navigation .menu >li >a:hover,
.main-navigation .menu >li >a:focus{
  color:'.$primary_color.';
}
.main-navigation .menu >li ul li a:hover,
.main-navigation .menu >li ul li a:focus{
  color:'.$primary_color.';
}
.entry-title a:hover,
.entry-title a:focus{
  color:'.$primary_color.';
}
.entry-meta a:hover,
.entry-meta a:focus{
  color:'.$primary_color.';
}
.entry-footer a:hover,
.entry-footer a:focus{
  color:'.$primary_color.';
}
.sticky-post{
  background:'.$primary_color.';
}
.divdate{
  background:'.$primary_color.';
}
.more-link:hover,
.more-link:focus{
  color:'.$primary_color.';
}
.widget >ul >li a:hover,
.widget >ul >li a:focus{
  color:'.$primary_color.';
}
.comment-meta a:hover,
.comment-meta a:focus{
  color:'.$primary_color.';
}
.comment-meta .fn a:hover,
.comment-meta .fn a:focus{
  color:'.$primary_color.';
}
.comment-reply-title small a:hover,
.comment-reply-title small a:focus{
  color:'.$primary_color.';
}
.comment-form .logged-in-as a:hover,
.comment-form .logged-in-as a:focus{
  color:'.$primary_color.';
}
.posts-navigation .nav-links a:hover,
.posts-navigation .nav-links a:focus{
  background:'.$primary_color.';
}
.pagination .nav-links a:hover,
.pagination .nav-links a:focus{
  background:'.$primary_color.';
}
.pagination .nav-links .current{
  background:'.$primary_color.';
}
#slider-title a {
  background: '.$primary_color.';
}
.owl-theme .owl-controls .owl-page:hover span, 
.owl-theme .owl-controls .owl-page:focus span, 
.owl-theme .owl-controls .active span{
  color: '.$primary_color.';
  background-color: '.$primary_color.';
}
.slider-wrap .owl-theme .owl-controls .owl-buttons div {
  color: '.$primary_color.';
}
.site-info a:hover,
.site-info a:focus{
  color: '.$primary_color.';
}
';
    }
    return $css;
  }
}
