<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package fred
 */

if ( ! function_exists( 'fred_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function fred_posted_on() {
  $time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
  if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
    $time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
  }

  $time_string = sprintf( $time_string,
    esc_attr( get_the_date( 'c' ) ),
    esc_html( get_the_date() ),
    esc_attr( get_the_modified_date( 'c' ) ),
    esc_html( get_the_modified_date() )
  );

  $posted_on = '<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>';

  $byline = '<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>';

  echo '<span class="posted-on"><i class="fa fa-calendar" aria-hidden="true"></i> ' . $posted_on . '</span><span class="byline"><i class="fa fa-user" aria-hidden="true"></i> ' . $byline . '</span>';
  
  edit_post_link( esc_html__( 'Edit', 'fred' ), '<span class="edit-link"><i class="fa fa-edit" aria-hidden="true"></i> ', '</span>' );

  if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
    echo '<span class="comments-link"><i class="fa fa-comments" aria-hidden="true"></i> ';
    comments_popup_link( esc_html__( 'Leave a comment', 'fred' ), esc_html__( '1 Comment', 'fred' ), esc_html__( '% Comments', 'fred' ) );
    echo '</span>';
  }
}
endif;

if ( ! function_exists( 'fred_entry_footer' ) ) :
  /**
   * Prints HTML with meta information for the categories, tags and comments.
   */
  function fred_entry_footer() {
    // Hide category and tag text for pages.
    if ( 'post' === get_post_type() ) {
      /* translators: used between list items, there is a space after the comma */
      $categories_list = get_the_category_list( esc_html__( ', ', 'fred' ) );
      if ( $categories_list ) {
        echo '<span class="cat-links"><i class="fa fa-list" aria-hidden="true"></i> ' . $categories_list . '</span>';
      }
  
      /* translators: used between list items, there is a space after the comma */
      $tags_list = get_the_tag_list( '', esc_html_x( ', ', 'list item separator', 'fred' ) );
      if ( $tags_list ) {
        echo '<span class="tags-links"><i class="fa fa-tags" aria-hidden="true"></i> ' . $tags_list . '</span>';
      }
    } 
  }
endif;

function fred_posts_navigation() {
  the_posts_navigation(array(
    'prev_text' => '<i class="fa fa-caret-left" aria-hidden="true"></i> '.esc_html__('Older posts','fred'),
    'next_text'  => esc_html__('Newer posts','fred').' <i class="fa fa-caret-right" aria-hidden="true"></i>'       
  ));
}

function fred_post_navigation(){
  the_post_navigation( array(
        'prev_text' => '<i class="fa fa-caret-left" aria-hidden="true"></i> %title',
        'next_text' => '%title <i class="fa fa-caret-right" aria-hidden="true"></i>'
  ) );
}

function fred_comments_navigation(){
  the_comments_navigation(array(
    'prev_text' => '<i class="fa fa-caret-left" aria-hidden="true"></i> '.esc_html__( 'Older comments' ,'fred'),
    'next_text' => esc_html__( 'Newer comments' ,'fred').' <i class="fa fa-caret-right" aria-hidden="true"></i>'
  ));
}

function fred_posts_pagination(){
  the_posts_pagination(array(
    'prev_text' => '<i class="fa fa-caret-left" aria-hidden="true"></i>',
    'next_text' => '<i class="fa fa-caret-right" aria-hidden="true"></i>'
  ));
}
